@@ -23,6 +23,15 @@
  * cpl_serv.c: Various Common Portability Library derived convenience functions
  *
  * $Log: cpl_serv.c,v $
+ * Revision 1.8  2001/07/09 20:14:37  warmerda
+ * Another problem freeing pszRLBuffer and not setting to NULL.
+ *
+ * Revision 1.7  2001/04/17 13:40:43  warmerda
+ * fixed freeing of line buffer in CPLReadLine(), init ptr to NULL
+ *
+ * Revision 1.6  2001/03/05 04:56:17  warmerda
+ * make it possible to deallocate CPLReadLine buffer
+ *
  * Revision 1.5  2000/09/30 03:35:05  warmerda
  * Fixed CPLReadLine() to use avoid calling VSIRealloc() on a NULL pointer.
  *
@@ -164,6 +173,17 @@ const char *CPLReadLine( FILE * fp )
     static int	nRLBufferSize = 0;
     int		nLength, nReadSoFar = 0;
 
+/* -------------------------------------------------------------------- */
+/*      Cleanup case.                                                   */
+/* -------------------------------------------------------------------- */
+    if( fp == NULL )
+    {
+        CPLFree( pszRLBuffer );
+        pszRLBuffer = NULL;
+        nRLBufferSize = 0;
+        return NULL;
+    }
+
 /* -------------------------------------------------------------------- */
 /*      Loop reading chunks of the line till we get to the end of       */
 /*      the line.                                                       */
@@ -193,7 +213,13 @@ const char *CPLReadLine( FILE * fp )
 /* -------------------------------------------------------------------- */
         if( VSIFGets( pszRLBuffer+nReadSoFar, nRLBufferSize-nReadSoFar, fp )
             == NULL )
+        {
+            CPLFree( pszRLBuffer );
+            pszRLBuffer = NULL;
+            nRLBufferSize = 0;
+
             return NULL;
+        }
 
         nReadSoFar = strlen(pszRLBuffer);
 
